@@ -52,7 +52,7 @@ class HttpClient(object):
 
     def _do_request(self, http_method, rest_command,
                     parameters=None,
-                    file=None):
+                    file=None, headers=None):
         """Perform a HTTP request.
 
         :param http_method: GET or POST.
@@ -71,11 +71,13 @@ class HttpClient(object):
                 with open(file, 'rb') as payload:
                     response = tls_session.request(http_method, cmd_url,
                                                    params=parameters,
-                                                   verify=False, data=payload)
+                                                   verify=False, data=payload,
+                                                   headers=headers)
             else:
                 response = tls_session.request(http_method, cmd_url,
                                                params=parameters,
-                                               timeout=5, verify=False)
+                                               timeout=5, verify=False,
+                                               headers=headers)
             if 400 < response.status_code < 500:
                 raise KempTechApiException(msg=response.text)
             else:
@@ -104,12 +106,13 @@ class HttpClient(object):
             raise
         return response.text
 
-    def _get(self, rest_command, parameters=None):
-        return self._do_request('GET', rest_command, parameters)
+    def _get(self, rest_command, parameters=None, headers=None):
+        return self._do_request('GET', rest_command, parameters,
+                                headers=headers)
 
-    def _post(self, rest_command, file=None, parameters=None):
+    def _post(self, rest_command, file=None, parameters=None, headers=None):
         return self._do_request('POST', rest_command, parameters=parameters,
-                                file=file)
+                                file=file, headers=headers)
 
 # ---- Models ---
 
